@@ -20,7 +20,7 @@ sub new
 sub parse_response
 {
     my $self = shift;
-    my $content =$_[0]->content;
+    my $content = $_[0]->decoded_content;
     # JSONP to pure JSON
     $content =~ s/[a-zA-Z_\$][a-zA-Z0-9_\$]*\s*\((.+)\)\s*;?\s*$/$1/;
     $self->{json}->decode( $content );
